package com.lizlam.terminal;

import android.content.Context;
import android.graphics.Color;
import android.net.ConnectivityManager;
import android.net.NetworkInfo;
import android.os.AsyncTask;
import android.os.Bundle;
import android.support.v7.app.ActionBarActivity;
import android.view.Menu;
import android.view.MenuItem;
import android.view.View;
import android.webkit.WebView;
import android.webkit.WebViewClient;
import android.widget.Button;
import android.widget.ProgressBar;
import android.widget.TextView;
import android.widget.Toast;


public class MainActivity extends ActionBarActivity {

    WebView wv;
    TextView tv;
    TextView tv_url;
    ProgressBar pb;

    final static String WEBSITE_URL = "http://www.lizlam.com";
    final static String ABOUT_URL = "http://www.lizlam.com/about.html";
    final static String BLOG_URL = "http://www.perforce.com/blog/author/llam";
    final static String TWITTER_URL = "http://www.twitter.com/p4liz";
    final static String CODE_URL = "https://swarm.workshop.perforce.com/files/guest/liz_lam";

    @Override
    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.activity_main);

        wv = (WebView) findViewById(R.id.webView);
        pb = (ProgressBar) findViewById(R.id.progressBar);
        pb.setVisibility(View.INVISIBLE);

        tv = (TextView) findViewById(R.id.textView2);
        tv_url = (TextView) findViewById(R.id.textView);

        if (savedInstanceState == null) {
            MyTask myTask = new MyTask();
            myTask.execute(WEBSITE_URL);
        }

        Button about = (Button) findViewById(R.id.button);
        about.setOnClickListener(new View.OnClickListener() {
            @Override
            public void onClick(View v) {
                if (isConnected()) {
                    getWebInfo(ABOUT_URL);
                } else {
                    showNetworkError();
                }
            }
        });

        Button blog = (Button) findViewById(R.id.button2);
        blog.setOnClickListener(new View.OnClickListener() {
            @Override
            public void onClick(View v) {
                if (isConnected()) {
                    getWebInfo(BLOG_URL);
                } else {
                    showNetworkError();
                }
            }
        });

        Button tweets = (Button) findViewById(R.id.button3);
        tweets.setOnClickListener(new View.OnClickListener() {
            @Override
            public void onClick(View v) {
                if (isConnected()) {
                    getWebInfo(TWITTER_URL);
                } else {
                    showNetworkError();
                }
            }
        });

        Button code = (Button) findViewById(R.id.button4);
        code.setOnClickListener(new View.OnClickListener() {
            @Override
            public void onClick(View v) {
                if (isConnected()) {
                    getWebInfo(CODE_URL);
                } else {
                    showNetworkError();
                }
            }
        });
    }

    @Override
    public boolean onCreateOptionsMenu(Menu menu) {
        // Inflate the menu; this adds items to the action bar if it is present.
        getMenuInflater().inflate(R.menu.menu_main, menu);
        return true;
    }

    @Override
    public boolean onOptionsItemSelected(MenuItem item) {
        // Handle action bar item clicks here. The action bar will
        // automatically handle clicks on the Home/Up button, so long
        // as you specify a parent activity in AndroidManifest.xml.
        int id = item.getItemId();

        //noinspection SimplifiableIfStatement
        if (id == R.id.action_settings) {
            updateDisplay("Version 1.0");
            return true;
        }

        return super.onOptionsItemSelected(item);
    }

    @Override
    public void onSaveInstanceState(Bundle savedInstanceState) {
        super.onSaveInstanceState(savedInstanceState);
        savedInstanceState.putString("current_url", tv_url.getText().toString());
    }

    @Override
    protected void onRestoreInstanceState(Bundle savedInstanceState) {
        super.onRestoreInstanceState(savedInstanceState);
        MyTask savedTask = new MyTask();
        savedTask.execute(savedInstanceState.getString("current_url"));
    }

    private void updateWebView(String url) {
        tv.setVisibility(View.INVISIBLE);
        wv.setVisibility(View.VISIBLE);
        wv.setWebViewClient(new WebViewClient());
        wv.getSettings().setLoadWithOverviewMode(true);
        wv.getSettings().setUseWideViewPort(true);
        wv.loadUrl(url);
    }

    private void updateDisplay(String string) {
        wv.setVisibility(View.INVISIBLE);
        tv.setVisibility(View.VISIBLE);
        tv.setBackgroundColor(Color.BLACK);
        tv.setTextColor(Color.GRAY);
        tv.setText(string);
    }

    private boolean isConnected() {
        ConnectivityManager cm = (ConnectivityManager) this.getSystemService(Context.CONNECTIVITY_SERVICE);
        NetworkInfo info = cm.getActiveNetworkInfo();
        if (info != null && info.isConnectedOrConnecting()) {
            return true;
        } else {
            return false;
        }
    }

    private void showNetworkError() {
        Toast.makeText(this, "Network not connected", Toast.LENGTH_LONG).show();
    }

    protected void getWebInfo(String webUrl) {
        MyTask myTask = new MyTask();
        myTask.execute(webUrl);
    }

    private class MyTask extends AsyncTask<String, String, String> {

        @Override
        protected void onPreExecute() {
            pb.setVisibility(View.VISIBLE);
        }

        @Override
        protected String doInBackground(String... params) {
            if (params[0].contains(TWITTER_URL)) {
                TwitterInfo ti = new TwitterInfo();
                String tweets = ti.getTweets();
                return tweets;
            } else if (params[0] != null) {
                return params[0];
            } else {
                return null;
            }
        }

        @Override
        protected void onPostExecute(String s) {
            if (s.contains("twitter")) {
                updateDisplay(s);
                tv_url.setText(TWITTER_URL);
            } else {
                updateWebView(s);
                tv_url.setText(s);
            }
            pb.setVisibility(View.INVISIBLE);
        }
    }
}
